# Etherscan_API

class GetResult: must get Ethereum address and API key Etherscan

get_eth_balance: return balance Ethereum address

get_erc20_balance: return balance ERC20 token Ethereum address

get_erc721_balance: must get provider_url

get_erc721_balance: return url for NFT images

Donate

BTC - 1J18ggoGFnbhAGg66aGScXTEJbk7S5Xu6S

ETH - 0x3AA1a0dAfC77Ea0fb28b84F1065565Ac25e82a94
